ChannelClosed class final

A channel was closed — either because the client left it or the server kicked it.

Inheritance

Constructors

ChannelClosed({required String topic, required String reason})
Creates a ChannelClosed event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
Human-readable reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String
Channel topic that closed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited