FakeChatTransportInject class
Event-injection API for driving test scenarios.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectionState(
TransportConnectionState state) → void -
Emits
statethrough the transport's connection state stream. -
conversationCreated(
String siteTopic, String convId) → void -
Registers a PushOk reply for
conversation:createonsiteTopic. -
event(
TransportEvent event) → void -
Emits
eventthrough the transport's events stream. -
joinPayload(
String topic, Map< String, dynamic> payload) → void -
Registers the payload that FakeChatTransport.joinChannel returns for
the given
topic. Used to simulate the Phoenix channel join response (e.g.{messages: [...]}for conversation channels). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replyFor(
{required String topic, required String event, required PushResult result}) → void -
Registers a canned
resultto return from the next matching FakeChatTransport.push call with the giventopicandevent. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited