FakeChataptorClientInject class

Scripting API for a FakeChataptorClient.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignAgent(AgentInfo agent) → void
Sets the agent surface. Emits on the (optional) assignedAgent stream.
completeNextSend(SendResult result) → void
Scripts the outcome of the next FakeChataptorClient.sendMessage call. Each call consumes one scripted result, FIFO order.
connectionState(ConnectionState state) → void
Transitions the fake into state and emits to connectionState.
message(Message message) → void
Emits message to listeners on messages and appends it to FakeChataptorClient.currentMessages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited