connectionState method
Transitions the fake into state and emits to connectionState.
Implementation
void connectionState(ConnectionState state) {
_client._currentConnectionState = state;
_client._connectionStateController.add(state);
}
Transitions the fake into state and emits to connectionState.
void connectionState(ConnectionState state) {
_client._currentConnectionState = state;
_client._connectionStateController.add(state);
}