PushOk class final

The push was acknowledged by the server.

Inheritance

Constructors

PushOk(Map<String, dynamic> response)
Creates a PushOk with the server's reply response.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
response Map<String, dynamic>
Server reply payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited