PushServerError class final

The server explicitly rejected the push.

Inheritance

Constructors

PushServerError({required String reason, required Map<String, dynamic> response})
Creates a PushServerError.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
Short human-readable reason.
final
response Map<String, dynamic>
Server reply payload (often contains details).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited