RecordedPush class

Record of a single call to FakeChatTransport.push.

Constructors

RecordedPush({required String topic, required String event, required Map<String, dynamic> payload})
Creates a RecordedPush entry.

Properties

event String
Phoenix event name.
final
hashCode int
The hash code for this object.
no setterinherited
payload Map<String, dynamic>
Payload passed to push.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String
Channel topic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited