RecordingChataptorLogger class

In-memory logger useful in tests. Captures every call.

Implemented types

Properties

entries List<ChataptorLogEntry>
Entries captured so far, in order.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(ChataptorLogLevel level, String message, {Object? error, StackTrace? stackTrace}) → void
Writes a single log entry.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited