TransportDisconnected class final
Transport is closed and not retrying (either due to user request or a fatal error).
- Inheritance
-
- Object
- TransportConnectionState
- TransportDisconnected
Constructors
- TransportDisconnected({required String reason})
-
Creates a TransportDisconnected state with a human-readable
reason.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited