TransportReconnecting class final
Transport lost its connection and is retrying.
- Inheritance
-
- Object
- TransportConnectionState
- TransportReconnecting
Constructors
- TransportReconnecting({required int attemptNumber, required Duration nextAttemptIn})
-
Creates a TransportReconnecting state.
const
Properties
- attemptNumber → int
-
1-based retry count.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextAttemptIn → Duration
-
Delay before the next retry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited