ChannelClosed class final
A channel was closed — either because the client left it or the server kicked it.
- Inheritance
-
- Object
- TransportEvent
- ChannelClosed
Constructors
- ChannelClosed({required String topic, required String reason})
-
Creates a ChannelClosed event.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited