connect method
Opens the WebSocket, joins the site channel, creates a conversation, and joins the conversation channel. Connected is emitted only after the full handshake completes. Idempotent.
Implementation
@override
Future<void> connect() async {
recorded.connectCalls += 1;
inject.connectionState(const Connected());
}