MessageReceived class final
The server pushed an event on topic.
- Inheritance
-
- Object
- TransportEvent
- MessageReceived
Constructors
-
MessageReceived({required String topic, required String event, required Map<
String, dynamic> payload}) -
Creates a MessageReceived event.
const
Properties
- event → String
-
Phoenix event name (e.g.
message:received).final - hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
→ Map<
String, dynamic> -
Raw payload map as emitted by the server.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topic → String
-
Channel topic (e.g.
site:abc-shop,conversation:42).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited