TransportDisconnected class final

Transport is closed and not retrying (either due to user request or a fatal error).

Inheritance

Constructors

TransportDisconnected({required String reason})
Creates a TransportDisconnected state with a human-readable reason.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
Human-readable disconnect reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited